import Dp from "@/dp";
import { ReduxState, store } from "@/redux/store";
import YSDK from "@/sdk";
import { getStatisticsRangMonth } from "@ray-js/ray"
import { useGetState, useSafeState } from "ahooks";
import dayjs from "dayjs";
import { useEffect, useRef, useState } from "react";
import { shallowEqual } from "react-redux";

export const useMonthEle = (devId: string) => {
    const [data, setData] = useState(0)
    useEffect(() => {
        if (devId) {
            const now = dayjs()
            const monthFormat = now.format('YYYYMM');
            getStatisticsRangMonth({
                devId,
                dpId: YSDK.dev.getDpIdByCode(Dp.electricityconsumption),
                startMonth: monthFormat,
                endMonth: monthFormat,
                type: 'sum',
            }).then(r => {
                setData(parseFloat(r[monthFormat] || '0'));
            });
        }
    }, [devId])

    return data
}


export const useSelect = <T,>(select: (state: ReduxState) => T) => {
    const [data, setData, getData] = useGetState<T>(() => select(store.getState() as ReduxState))
    useEffect(() => {
        const s = store.subscribe(() => {
            const newData = select(store.getState());
            shallowEqual(getData(), newData)
            setData(newData)
        })
        return () => {
            s()
        }
    }, [])
    return data
}