import Strings from "@/i18n"
import YSDK from "@/sdk";
import { DPNumberInfo } from "@/types";

const splitRange = (range: string) => {
    const [min, max] = range.split("-")
    return {
        min: min === '' ? Number.MIN_VALUE : Number(min),
        max: max === '' ? Number.MAX_VALUE : Number(max),
    };
}

export const getLevelRange = (dp: string) => {
    return [
        splitRange(Strings.getLang(`${dp}_level1_range`)),
        splitRange(Strings.getLang(`${dp}_level2_range`)),
        splitRange(Strings.getLang(`${dp}_level3_range`)),
        splitRange(Strings.getLang(`${dp}_level4_range`)),
    ]
}

export const range2text = ({ min, max }: { min: number, max: number }) => {
    if (min !== Number.MIN_VALUE && max !== Number.MAX_VALUE) {
        return `${min}~${max}`
    } else if (min !== Number.MIN_VALUE) {
        return `<${min}`
    } else if (max !== Number.MAX_VALUE) {
        return `>${max}`
    }
    return '';
}

export const getLevel = (dp: string, value: number) => {
    const range = getLevelRange(dp)
    for (let i = 0; i < range.length; i++) {
        const { min, max } = range[i]
        if (value >= min && value < max) {
            return i;
        }
    }
    return 0;
}

export const getSuggestScop = (dp: string) => {
    return Strings.getLang(`${dp}_suggest_scope`);
}

export const getLevelColor = (level: string) => {
    return Strings.getLang(`level${level}_color`);
}

export const getUnit = (dp) => {
    return (YSDK.dev.getDpInfoByCode(dp) as DPNumberInfo).typeSpec?.unit || ""
}

export const scale = (dp: any, value: number) => {
    return value / (10 ** YSDK.dev.getScale(dp))
}